@@ -95,7 +95,7 @@ GUI framework demo implementations
 the plan is to integrate the following GUI frameworks on top of the :class:`abstract base class <~.gui_app.MainAppBase>`
 (implemented in the :mod:`ae.gui_app` portion of the `ae namespace <https://ae.readthedocs.io>`__):
 
-* :mod:`Kivy <ae.kivy>` based on the `kivy framework <https://kivy.org>`__:
+* :mod:`Kivy <ae.kivy>` based on the `Kivy framework <https://kivy.org>`__:
   `kivy lisz demo app <https://gitlab.com/ae-group/kivy_lisz>`__
 * :mod:`Enaml <ae.enaml_app>` based on `the enaml framework <https://enaml.readthedocs.io/en/latest/>`__:
   `enaml lisz demo app <https://gitlab.com/ae-group/enaml_lisz>`__
@@ -118,7 +118,7 @@ gui framework implementation variants
 kivy
 ----
 
-the `kivy lisz app <https://gitlab.com/ae-group/kivy_lisz>`__ is based on the `kivy framework <https://kivy.org>`__, a
+the `kivy lisz app <https://gitlab.com/ae-group/kivy_lisz>`__ is based on the `Kivy framework <https://kivy.org>`__, a
 `pypi package <https://pypi.org/project/Kivy/>`__ documented `here <https://kivy.org/doc/stable/>`__.
 
 .. list-table::
@@ -227,7 +227,7 @@ from ae.core import DEBUG_LEVEL_VERBOSE
 from ae.gui_app import id_of_flow, flow_action, flow_key, flow_path_strip, replace_flow_action  # type: ignore
 
 
-__version__ = '0.3.50'
+__version__ = '0.3.51'
 
 
 FLOW_PATH_ROOT_ID = '^^^^'  #: pseudo item id needed for flow path jumper and for drop onto leave item button
