@@ -38,10 +38,6 @@ class AppTest(LiszDataMixin, MainAppBase):
         self.current_node_items = self.root_node
         self.filtered_indexes = []
 
-    def on_app_start(self):
-        """ needed to test call LiszDataMixin.on_start_up() because is mixed in after MainAppBase. """
-        super().on_app_start()
-
     def refresh_node_widgets(self):
         """ redraw widgets for each item of the current node. """
 
@@ -717,9 +713,9 @@ class TestLiszDataMixin:
         super(AppTest, app).on_app_init()
         assert app.current_node_items == []
 
-    def test_on_app_start(self, restore_app_env):
+    def test_on_app_run(self, restore_app_env):
         app = AppTest()
-        app.on_app_start()
+        app.on_app_run()
         assert app.current_node_items == []
 
     def test_on_app_state_key_save(self, restore_app_env):
